@@ -177,18 +177,13 @@ def save_dataset_local(
             outfile.write(value)
         print(f"Saved external output data to {output_file_path}")
     else:
-        # job_id = variables.get("PA_JOB_ID")
-        # task_id = variables.get("PA_TASK_ID")
-        # task_folder = os.path.join("/shared", job_id, task_id)
         workflow_id = exp_engine_metadata["wf_id"]
         task_name = variables.get("task_name")
-        # task_name = variables.get("PA_TASK_NAME")
         task_folder = os.path.join("/shared", workflow_id, task_name)
         os.makedirs(task_folder, exist_ok=True)
         output_file_path = os.path.join(task_folder, key)
         with open(output_file_path, "wb") as outfile:
             pickle.dump(value, outfile)
-        # variables.put("PREVIOUS_TASK_ID", str(task_id))
         print(f"Saved intermediate output data to {output_file_path}")
 
     if resultMap is not None:
@@ -211,13 +206,11 @@ def save_datasets_ddm(
         raise ConfigurationError("DDM_TOKEN is required when DATASET_MANAGEMENT=DDM")
 
     # Validate required keys
-    validate_variables_has_key(variables, "PA_TASK_NAME", "variables")
-    validate_variables_has_key(variables, "PA_JOB_NAME", "variables")
+    validate_variables_has_key(variables, "task_name", "variables")
 
     upload_url = f"{DDM_URL}/ddm/files/upload"
     file_url_template = f"{DDM_URL}/ddm/file/{{}}"
-    task_name = variables['PA_TASK_NAME']
-    variables.put("PREVIOUS_TASK_ID", str(task_name))
+    task_name = variables.get("task_name")
 
     project_id_prefix = os.path.join(exp_engine_metadata["exp_name"],
                                      exp_engine_metadata["exp_id"],
@@ -358,8 +351,6 @@ def load_dataset_local(variables: Dict[str, Any], key: str) -> Any:
     print(f"Loading input data with key '{key}'")
 
     # Validate required keys
-    # validate_variables_has_key(variables, "PA_JOB_ID", "variables")
-    # validate_variables_has_key(variables, "PA_TASK_NAME", "variables")
     validate_variables_has_key(variables, "task_name", "variables")
 
     if key in variables:
@@ -367,10 +358,6 @@ def load_dataset_local(variables: Dict[str, Any], key: str) -> Any:
         print(f"Loading external input data from {input_filename}")
         return load_dataset_by_path(input_filename)
     else:
-        # job_id = variables.get("PA_JOB_ID")
-        # task_id = variables.get("PREVIOUS_TASK_ID")
-        # task_folder = os.path.join("/shared", job_id, task_id)
-        # task_name = variables.get("PA_TASK_NAME")
         task_name = variables.get("task_name")
         workflow_id = exp_engine_metadata["wf_id"]
         if task_name in execution_engine_mapping:
@@ -379,8 +366,6 @@ def load_dataset_local(variables: Dict[str, Any], key: str) -> Any:
                 input_map = inputs[key]
                 output_name = input_map["file_name"]
                 source_task = input_map["source_task"]
-            # if key in execution_engine_mapping[task_name]:
-            #     key = execution_engine_mapping[task_name][key]
         task_folder = os.path.join("/shared", workflow_id, source_task)
         input_filename = os.path.join(task_folder, output_name)
         print(f"Loading intermediate input data from {input_filename}")
@@ -400,10 +385,10 @@ def load_datasets_ddm(
         raise ConfigurationError("DDM_TOKEN is required when DATASET_MANAGEMENT=DDM")
 
     # Validate required keys
-    validate_variables_has_key(variables, "PA_TASK_NAME", "variables")
+    validate_variables_has_key(variables, "task_name", "variables")
 
     file_url_template = f"{DDM_URL}/ddm/file/{{}}"
-    task_name = variables.get("PA_TASK_NAME")
+    task_name = variables.get("task_name")
     if key in variables:
         file_type = FILE_TYPE_EXTERNAL
         ddm_value = variables.get(key)
@@ -412,15 +397,17 @@ def load_datasets_ddm(
         project_id = ddm_value_parts[1]
     else:
         file_type = FILE_TYPE_INTERMEDIATE
-        fname = key
         if task_name in execution_engine_mapping:
-            if fname in execution_engine_mapping[task_name]:
-                fname = execution_engine_mapping[task_name][fname]
-        task_id = variables.get("PREVIOUS_TASK_ID")
+            inputs = execution_engine_mapping[task_name]
+            if key in inputs:
+                input_map = inputs[key]
+                fname = input_map["file_name"]
+                source_task = input_map["source_task"]
+
         project_id_prefix = os.path.join(exp_engine_metadata["exp_name"],
                                          exp_engine_metadata["exp_id"],
                                          exp_engine_metadata["wf_id"])
-        project_id = os.path.join(project_id_prefix, OUTPUT_FILE, task_id)
+        project_id = os.path.join(project_id_prefix, OUTPUT_FILE, source_task)
     results = _look_up_file_in_catalog(fname, project_id)
 
     contents = []
